@@ -16,14 +16,13 @@ import click
 
 from osducli.click_cli import CustomClickCommand, State, command_with_output
 from osducli.cliclient import handle_cli_exceptions
-from osducli.config import CONFIG_ENTITLEMENTS_URL
-from osducli.util.service_info import info
-
-from ._const import (
+from osducli.commands.entitlements._const import (
     ENTITLEMENTS_SERVICE_NAME,
     ENTITLEMENTS_STATUS_PATH,
     ENTITLEMENTS_SWAGGER_PATH,
 )
+from osducli.config import CONFIG_ENTITLEMENTS_URL
+from osducli.util.service_info import info
 
 
 # click entry point
