@@ -14,13 +14,13 @@
 
 import click
 
-from osducli.click_cli import State, command_with_output
+from osducli.click_cli import CustomClickCommand, State, command_with_output
 from osducli.cliclient import CliOsduClient, handle_cli_exceptions
 from osducli.config import CONFIG_SCHEMA_URL
 
 
 # click entry point
-@click.command()
+@click.command(cls=CustomClickCommand)
 @click.option("-k", "--kind", required=True, help="Kind of the schema")
 @handle_cli_exceptions
 @command_with_output(None)
