@@ -16,13 +16,13 @@ from urllib.parse import quote_plus
 
 import click
 
-from osducli.click_cli import State, command_with_output
+from osducli.click_cli import CustomClickCommand, State, command_with_output
 from osducli.cliclient import CliOsduClient, handle_cli_exceptions
 from osducli.config import CONFIG_SCHEMA_URL
 
 
 # click entry point
-@click.command()
+@click.command(cls=CustomClickCommand)
 @click.option("-a", "--authority", help="Authority to filter by")
 @click.option("-e", "--entity", help="Entity to filter by")
 @click.option("-s", "--source", help="Source to filter by")
